<?php

namespace B2buy\Order\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use B2buy\Order\Http\Requests\OrderProductRequest;
use B2buy\Order\Interfaces\OrderProductRepositoryInterface;
use B2buy\Order\Models\OrderProduct;

/**
 * Resource controller class for order_product.
 */
class OrderProductResourceController extends BaseController
{

    /**
     * Initialize order_product resource controller.
     *
     * @param type OrderProductRepositoryInterface $order_product
     *
     * @return null
     */
    public function __construct(OrderProductRepositoryInterface $order_product)
    {
        parent::__construct();
        $this->repository = $order_product;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Order\Repositories\Criteria\OrderProductResourceCriteria::class);
    }

    /**
     * Display a list of order_product.
     *
     * @return Response
     */
    public function index(OrderProductRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\B2buy\Order\Repositories\Presenter\OrderProductPresenter::class)
                ->$function();
        }

        $order_products = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('order::order_product.names'))
            ->view('order::order_product.index', true)
            ->data(compact('order_products', 'view'))
            ->output();
    }

    /**
     * Display order_product.
     *
     * @param Request $request
     * @param Model   $order_product
     *
     * @return Response
     */
    public function show(OrderProductRequest $request, OrderProduct $order_product)
    {

        if ($order_product->exists) {
            $view = 'order::order_product.show';
        } else {
            $view = 'order::order_product.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('order::order_product.name'))
            ->data(compact('order_product'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new order_product.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrderProductRequest $request)
    {

        $order_product = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('order::order_product.name')) 
            ->view('order::order_product.create', true) 
            ->data(compact('order_product'))
            ->output();
    }

    /**
     * Create new order_product.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrderProductRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $order_product                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('order::order_product.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('order/order_product/' . $order_product->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/order/order_product'))
                ->redirect();
        }

    }

    /**
     * Show order_product for editing.
     *
     * @param Request $request
     * @param Model   $order_product
     *
     * @return Response
     */
    public function edit(OrderProductRequest $request, OrderProduct $order_product)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('order::order_product.name'))
            ->view('order::order_product.edit', true)
            ->data(compact('order_product'))
            ->output();
    }

    /**
     * Update the order_product.
     *
     * @param Request $request
     * @param Model   $order_product
     *
     * @return Response
     */
    public function update(OrderProductRequest $request, OrderProduct $order_product)
    {
        try {
            $attributes = $request->all();

            $order_product->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('order::order_product.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('order/order_product/' . $order_product->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('order/order_product/' . $order_product->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the order_product.
     *
     * @param Model   $order_product
     *
     * @return Response
     */
    public function destroy(OrderProductRequest $request, OrderProduct $order_product)
    {
        try {

            $order_product->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('order::order_product.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('order/order_product/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('order/order_product/' . $order_product->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple order_product.
     *
     * @param Model   $order_product
     *
     * @return Response
     */
    public function delete(OrderProductRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('order::order_product.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('order/order_product'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/order/order_product'))
                ->redirect();
        }

    }

    /**
     * Restore deleted order_products.
     *
     * @param Model   $order_product
     *
     * @return Response
     */
    public function restore(OrderProductRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('order::order_product.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/order/order_product'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/order/order_product/'))
                ->redirect();
        }

    }

}
